sqlobject.tests.test_perConnection module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_perConnection module

class `sqlobject.tests.test_perConnection.` `SOTestPerConnection`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = so_test_per_connection
  `q` = so_test_per_connection
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_perConnection.SOTestPerConnection`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'so_test_per_connection'
  property `test`

`sqlobject.tests.test_perConnection.` `test_perConnection`()